@@ -87,12 +87,12 @@ find_random.afex_aov <- function(x, split_nested = FALSE, flatten = FALSE) {
       r1 <- unique(unlist(lapply(
         f$random,
         .get_model_random,
-        split_nested,
-        model = x
+        model = x,
+        split_nested = split_nested
       ), use.names = FALSE))
     } else {
       r1 <- unique(unlist(
-        .get_model_random(f$random, split_nested, x),
+        .get_model_random(f$random, model = x, split_nested),
         use.names = FALSE
       ))
     }
@@ -104,11 +104,11 @@ find_random.afex_aov <- function(x, split_nested = FALSE, flatten = FALSE) {
   if (object_has_names(f, "zero_inflated_random")) {
     if (is.list(f$zero_inflated_random)) {
       r2 <- unique(unlist(
-        lapply(f$zero_inflated_random, .get_model_random, split_nested, model = x),
+        lapply(f$zero_inflated_random, .get_model_random, model = x, split_nested = split_nested),
         use.names = FALSE
       ))
     } else {
-      r2 <- unique(.get_model_random(f$zero_inflated_random, split_nested, x))
+      r2 <- unique(.get_model_random(f$zero_inflated_random, model = x, split_nested))
     }
   } else {
     r2 <- NULL
