@@ -37,7 +37,7 @@
 #' degrees of freedom. For models of class `glmmTMB`, dispersion is
 #' \ifelse{html}{\out{&sigma;<sup>2</sup>}}{\eqn{\sigma^2}}.
 #' }
-#' \subsection{\pkg{brms} models}{
+#' \subsection{**brms** models}{
 #' For models of class `brmsfit`, there are different options for the
 #' `type` argument. See a list of supported auxiliary parameters here:
 #' [find_parameters.BGGM()].
@@ -53,7 +53,12 @@
 #' model <- glm(lot1 ~ log(u), data = clotting, family = Gamma())
 #' get_auxiliary(model, type = "dispersion") # same as summary(model)$dispersion
 #' @export
-get_auxiliary <- function(x, type = "sigma", summary = TRUE, centrality = "mean", verbose = TRUE, ...) {
+get_auxiliary <- function(x,
+                          type = "sigma",
+                          summary = TRUE,
+                          centrality = "mean",
+                          verbose = TRUE,
+                          ...) {
   type <- match.arg(type, choices = .aux_elements())
 
   if (inherits(x, "brmsfit")) {
@@ -84,8 +89,8 @@ get_dispersion.model_fit <- function(x, ...) {
 }
 
 
-get_dispersion.glm <- function(x, ...) {
-  info <- model_info(x)
+get_dispersion.glm <- function(x, verbose = TRUE, ...) {
+  info <- model_info(x, verbose = verbose)
   disp <- NULL
 
   if (info$is_poisson || info$is_binomial || info$is_negbin) {
@@ -99,8 +104,8 @@ get_dispersion.glm <- function(x, ...) {
 }
 
 
-get_dispersion.glmerMod <- function(x, ...) {
-  info <- model_info(x)
+get_dispersion.glmerMod <- function(x, verbose = TRUE, ...) {
+  info <- model_info(x, verbose = verbose)
   disp <- NULL
 
   if (info$is_poisson || info$is_binomial || info$is_negbin) {
@@ -118,8 +123,8 @@ get_dispersion.glmerMod <- function(x, ...) {
 }
 
 
-get_dispersion.glmmTMB <- function(x, ...) {
-  info <- model_info(x)
+get_dispersion.glmmTMB <- function(x, verbose = TRUE, ...) {
+  info <- model_info(x, verbose = verbose)
   disp <- NULL
 
   if (info$is_poisson || info$is_binomial || info$is_negbin) {
@@ -137,8 +142,11 @@ get_dispersion.brmsfit <- get_dispersion.glmmTMB
 
 # special ------------------
 
-
-.get_generic_aux <- function(x, param, summary = TRUE, centrality = "mean", ...) {
+.get_generic_aux <- function(x,
+                             param,
+                             summary = TRUE,
+                             centrality = "mean",
+                             ...) {
   aux <- NULL
   if (inherits(x, "brmsfit")) {
     aux <- as.data.frame(x)[[param]]
