@@ -17,9 +17,9 @@
 #' treatment <- gl(3, 3)
 #' m <- glm(counts ~ outcome + treatment, family = poisson())
 #'
-#' link_function(m)(.3)
+#' link_function(m)(0.3)
 #' # same as
-#' log(.3)
+#' log(0.3)
 #' @export
 link_function <- function(x, ...) {
   UseMethod("link_function")
@@ -432,18 +432,18 @@ link_function.robmixglm <- function(x, ...) {
 #' @export
 link_function.MCMCglmm <- function(x, ...) {
   switch(x$Residual$original.family,
-    "cengaussian" = ,
-    "gaussian" = stats::gaussian(link = "identity")$linkfun,
-    "categorical" = ,
-    "multinomial" = ,
-    "zibinomial" = ,
-    "ordinal" = stats::make.link("logit")$linkfun,
-    "poisson" = ,
-    "cenpoisson" = ,
-    "zipoisson" = ,
-    "zapoisson" = ,
-    "ztpoisson" = ,
-    "hupoisson" = stats::make.link("log")$linkfun
+    cengaussian = ,
+    gaussian = stats::gaussian(link = "identity")$linkfun,
+    categorical = ,
+    multinomial = ,
+    zibinomial = ,
+    ordinal = stats::make.link("logit")$linkfun,
+    poisson = ,
+    cenpoisson = ,
+    zipoisson = ,
+    zapoisson = ,
+    ztpoisson = ,
+    hupoisson = stats::make.link("log")$linkfun
   )
 }
 
@@ -471,10 +471,10 @@ link_function.fixest <- function(x, ...) {
     x$family$linkfun
   } else {
     link <- switch(x$family,
-      "poisson" = ,
-      "negbin" = "log",
-      "logit" = "logit",
-      "gaussian" = "identity"
+      poisson = ,
+      negbin = "log",
+      logit = "logit",
+      gaussian = "identity"
     )
     stats::make.link(link)$linkfun
   }
@@ -569,9 +569,9 @@ link_function.glmmadmb <- function(x, ...) {
 #' @export
 link_function.glmm <- function(x, ...) {
   switch(tolower(x$family.glmm$family.glmm),
-    "bernoulli.glmm" = ,
-    "binomial.glmm" = stats::make.link("logit")$linkfun,
-    "poisson.glmm" = stats::make.link("log")$linkfun,
+    bernoulli.glmm = ,
+    binomial.glmm = stats::make.link("logit")$linkfun,
+    poisson.glmm = stats::make.link("log")$linkfun,
     stats::gaussian(link = "identity")$linkfun
   )
 }
@@ -584,10 +584,10 @@ link_function.gamlss <- function(x, what = c("mu", "sigma", "nu", "tau"), ...) {
   what <- match.arg(what)
   faminfo <- get(x$family[1], asNamespace("gamlss"))()
   switch(what,
-    "mu" = faminfo$mu.linkfun,
-    "sigma" = faminfo$sigma.linkfun,
-    "nu" = faminfo$nu.linkfun,
-    "tau" = faminfo$tau.linkfun,
+    mu = faminfo$mu.linkfun,
+    sigma = faminfo$sigma.linkfun,
+    nu = faminfo$nu.linkfun,
+    tau = faminfo$tau.linkfun,
     faminfo$mu.linkfun
   )
 }
@@ -681,8 +681,8 @@ link_function.svyolr <- function(x, ...) {
 link_function.betareg <- function(x, what = c("mean", "precision"), ...) {
   what <- match.arg(what)
   switch(what,
-    "mean" = x$link$mean$linkfun,
-    "precision" = x$link$precision$linkfun
+    mean = x$link$mean$linkfun,
+    precision = x$link$precision$linkfun
   )
 }
 
@@ -696,8 +696,8 @@ link_function.DirichletRegModel <- function(x, what = c("mean", "precision"), ..
     stats::make.link("logit")$linkfun
   } else {
     switch(what,
-      "mean" = stats::make.link("logit")$linkfun,
-      "precision" = stats::make.link("log")$linkfun
+      mean = stats::make.link("logit")$linkfun,
+      precision = stats::make.link("log")$linkfun
     )
   }
 }
