@@ -1109,7 +1109,7 @@ model_info.glmmTMB <- function(x, ...) {
   check_if_installed("lme4")
 
   faminfo <- stats::family(x)
-  zero_inflated <- !is_empty_object(lme4::fixef(x)$zi)
+  zero_inflated <- !is_empty_object(lme4::fixef(x)$zi) || startsWith(faminfo$family, "truncated")
 
   .make_family(
     x = x,
@@ -1366,3 +1366,8 @@ model_info.earth <- function(x, ...) {
 model_info.deltaMethod <- function(x, ...) {
   NULL
 }
+
+#' @export
+model_info.ggcomparisons <- function(x, ...) {
+  NULL
+}
