@@ -88,7 +88,7 @@ n_obs.glm <- function(x, disaggregate = FALSE, ...) {
       }
 
       # response is a fraction
-    } else if (!is.data.frame(resp_data) && .is.fraction(resp_data)) {
+    } else if (!is.data.frame(resp_data) && .is_fraction(resp_data)) {
       .nobs <- sum(get_weights(x))
     }
     .nobs <- as.integer(.nobs)
@@ -134,10 +134,10 @@ n_obs.HLfit <- function(x, ...) {
 
 #' @export
 n_obs.gam <- function(x, ...) {
-  if (!is.null(dim(x$y))) {
-    dim(x$y)[1]
-  } else {
+  if (is.null(dim(x$y))) {
     length(x$y)
+  } else {
+    dim(x$y)[1]
   }
 }
 
